@@ -11,7 +11,6 @@ import ssl
 import yaml
 import json
 import time
-import pathlib
 import logging
 import configparser
 import threading
@@ -29,7 +28,6 @@ pd.set_option('display.width', None)
 
 app_timestamp = str(time.time()).split('.')[0]
 class_transfer_broker_ = TransferBroker()
-here = pathlib.Path(__file__).parent.resolve()
 
 def load_yaml(filename):
     """Function to load a yaml file.
@@ -179,7 +177,7 @@ def send_email(params, message):
     df_last_event = inspect_transfers(params)
     data_gigabytes, throughput_gigabits, parallel_transfers, queued_transfers, timestamp = get_metrics_link(df_last_event)
     # Write content of the email into a txt file
-    with open(here / 'logs/noted_email.txt', 'w') as f:
+    with open(''.join([os.getcwd(), '/noted/logs/noted_email.txt']), 'w') as f:
         f.write('From: noted@cern.ch\n')
         f.write('To: ' + str(class_transfer_broker_.get_list_email_address()) + '\n')
         f.write('Subject: [NOTED] Notification\n\n')
@@ -200,7 +198,7 @@ def send_email(params, message):
         f.write('Cheers,\n')
         f.write('NOTED\n')
     # Send email
-    cmd = os.popen('sendmail -vt < ' + here / 'logs/noted_email.txt')
+    cmd = os.popen('sendmail -vt < ' + ''.join([os.getcwd(), '/noted/logs/noted_email.txt']))
     return
 
 def get_fts_optimizer_events(cmd):
@@ -539,11 +537,12 @@ def main():
 
     """Main function."""
     # Logging
-    logging.basicConfig(level = logging.NOTSET, filename = here / str('logs/transfer_broker_' + app_timestamp + '.log'), filemode = 'w', format = '%(asctime)s %(name)s - %(levelname)s - %(threadName)s: %(message)s')
+    logging.basicConfig(level = logging.NOTSET, filename = ''.join([os.getcwd(), '/noted/logs/transfer_broker_' + app_timestamp + '.log']), filemode = 'w', format = '%(asctime)s %(name)s - %(levelname)s - %(threadName)s: %(message)s')
     logging.getLogger('numexpr.utils').setLevel(logging.WARNING) # hide logging messages from numexpr.utils module
     # Config parser
     params = configparser.ConfigParser(interpolation = configparser.ExtendedInterpolation())
-    params.read(here / 'params/params.ini')
+    params.read(''.join([os.path.dirname, os.path.realpath(__file__), '/params/params.ini']))
+    print('holii ', ''.join([os.path.dirname, os.path.realpath(__file__), '/params/params.ini']))
     # Argument parser
     args_parser = ArgumentParser(description = 'NOTED: a framework to optimise network traffic via the analysis of data from File Transfer Services.')
     args_parser.add_argument('config_file', help = 'the name of the configuration file [config-example.yaml]')
